# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlTuningTaskSqlExecutionPlanStep(object):
    """
    A step in the SQL execution plan.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlTuningTaskSqlExecutionPlanStep object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param plan_hash_value:
            The value to assign to the plan_hash_value property of this SqlTuningTaskSqlExecutionPlanStep.
        :type plan_hash_value: int

        :param step_id:
            The value to assign to the step_id property of this SqlTuningTaskSqlExecutionPlanStep.
        :type step_id: int

        :param parent_step_id:
            The value to assign to the parent_step_id property of this SqlTuningTaskSqlExecutionPlanStep.
        :type parent_step_id: int

        :param position:
            The value to assign to the position property of this SqlTuningTaskSqlExecutionPlanStep.
        :type position: int

        :param operation:
            The value to assign to the operation property of this SqlTuningTaskSqlExecutionPlanStep.
        :type operation: str

        :param options:
            The value to assign to the options property of this SqlTuningTaskSqlExecutionPlanStep.
        :type options: str

        :param optimizer_mode:
            The value to assign to the optimizer_mode property of this SqlTuningTaskSqlExecutionPlanStep.
        :type optimizer_mode: str

        :param cost:
            The value to assign to the cost property of this SqlTuningTaskSqlExecutionPlanStep.
        :type cost: float

        :param cardinality:
            The value to assign to the cardinality property of this SqlTuningTaskSqlExecutionPlanStep.
        :type cardinality: int

        :param bytes:
            The value to assign to the bytes property of this SqlTuningTaskSqlExecutionPlanStep.
        :type bytes: int

        :param cpu_cost:
            The value to assign to the cpu_cost property of this SqlTuningTaskSqlExecutionPlanStep.
        :type cpu_cost: float

        :param io_cost:
            The value to assign to the io_cost property of this SqlTuningTaskSqlExecutionPlanStep.
        :type io_cost: float

        :param temp_space:
            The value to assign to the temp_space property of this SqlTuningTaskSqlExecutionPlanStep.
        :type temp_space: int

        :param time:
            The value to assign to the time property of this SqlTuningTaskSqlExecutionPlanStep.
        :type time: int

        :param object_node:
            The value to assign to the object_node property of this SqlTuningTaskSqlExecutionPlanStep.
        :type object_node: str

        :param object_owner:
            The value to assign to the object_owner property of this SqlTuningTaskSqlExecutionPlanStep.
        :type object_owner: str

        :param object_name:
            The value to assign to the object_name property of this SqlTuningTaskSqlExecutionPlanStep.
        :type object_name: str

        :param object_position:
            The value to assign to the object_position property of this SqlTuningTaskSqlExecutionPlanStep.
        :type object_position: int

        :param object_type:
            The value to assign to the object_type property of this SqlTuningTaskSqlExecutionPlanStep.
        :type object_type: str

        :param partition_start:
            The value to assign to the partition_start property of this SqlTuningTaskSqlExecutionPlanStep.
        :type partition_start: str

        :param partition_stop:
            The value to assign to the partition_stop property of this SqlTuningTaskSqlExecutionPlanStep.
        :type partition_stop: str

        :param partition_id:
            The value to assign to the partition_id property of this SqlTuningTaskSqlExecutionPlanStep.
        :type partition_id: int

        :param remarks:
            The value to assign to the remarks property of this SqlTuningTaskSqlExecutionPlanStep.
        :type remarks: str

        :param number_of_search_column:
            The value to assign to the number_of_search_column property of this SqlTuningTaskSqlExecutionPlanStep.
        :type number_of_search_column: int

        :param other:
            The value to assign to the other property of this SqlTuningTaskSqlExecutionPlanStep.
        :type other: str

        :param other_tag:
            The value to assign to the other_tag property of this SqlTuningTaskSqlExecutionPlanStep.
        :type other_tag: str

        :param attribute:
            The value to assign to the attribute property of this SqlTuningTaskSqlExecutionPlanStep.
        :type attribute: str

        :param access_predicates:
            The value to assign to the access_predicates property of this SqlTuningTaskSqlExecutionPlanStep.
        :type access_predicates: str

        :param filter_predicates:
            The value to assign to the filter_predicates property of this SqlTuningTaskSqlExecutionPlanStep.
        :type filter_predicates: str

        """
        self.swagger_types = {
            'plan_hash_value': 'int',
            'step_id': 'int',
            'parent_step_id': 'int',
            'position': 'int',
            'operation': 'str',
            'options': 'str',
            'optimizer_mode': 'str',
            'cost': 'float',
            'cardinality': 'int',
            'bytes': 'int',
            'cpu_cost': 'float',
            'io_cost': 'float',
            'temp_space': 'int',
            'time': 'int',
            'object_node': 'str',
            'object_owner': 'str',
            'object_name': 'str',
            'object_position': 'int',
            'object_type': 'str',
            'partition_start': 'str',
            'partition_stop': 'str',
            'partition_id': 'int',
            'remarks': 'str',
            'number_of_search_column': 'int',
            'other': 'str',
            'other_tag': 'str',
            'attribute': 'str',
            'access_predicates': 'str',
            'filter_predicates': 'str'
        }

        self.attribute_map = {
            'plan_hash_value': 'planHashValue',
            'step_id': 'stepId',
            'parent_step_id': 'parentStepId',
            'position': 'position',
            'operation': 'operation',
            'options': 'options',
            'optimizer_mode': 'optimizerMode',
            'cost': 'cost',
            'cardinality': 'cardinality',
            'bytes': 'bytes',
            'cpu_cost': 'cpuCost',
            'io_cost': 'ioCost',
            'temp_space': 'tempSpace',
            'time': 'time',
            'object_node': 'objectNode',
            'object_owner': 'objectOwner',
            'object_name': 'objectName',
            'object_position': 'objectPosition',
            'object_type': 'objectType',
            'partition_start': 'partitionStart',
            'partition_stop': 'partitionStop',
            'partition_id': 'partitionId',
            'remarks': 'remarks',
            'number_of_search_column': 'numberOfSearchColumn',
            'other': 'other',
            'other_tag': 'otherTag',
            'attribute': 'attribute',
            'access_predicates': 'accessPredicates',
            'filter_predicates': 'filterPredicates'
        }

        self._plan_hash_value = None
        self._step_id = None
        self._parent_step_id = None
        self._position = None
        self._operation = None
        self._options = None
        self._optimizer_mode = None
        self._cost = None
        self._cardinality = None
        self._bytes = None
        self._cpu_cost = None
        self._io_cost = None
        self._temp_space = None
        self._time = None
        self._object_node = None
        self._object_owner = None
        self._object_name = None
        self._object_position = None
        self._object_type = None
        self._partition_start = None
        self._partition_stop = None
        self._partition_id = None
        self._remarks = None
        self._number_of_search_column = None
        self._other = None
        self._other_tag = None
        self._attribute = None
        self._access_predicates = None
        self._filter_predicates = None

    @property
    def plan_hash_value(self):
        """
        Gets the plan_hash_value of this SqlTuningTaskSqlExecutionPlanStep.
        The numerical representation of the SQL execution plan.


        :return: The plan_hash_value of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: int
        """
        return self._plan_hash_value

    @plan_hash_value.setter
    def plan_hash_value(self, plan_hash_value):
        """
        Sets the plan_hash_value of this SqlTuningTaskSqlExecutionPlanStep.
        The numerical representation of the SQL execution plan.


        :param plan_hash_value: The plan_hash_value of this SqlTuningTaskSqlExecutionPlanStep.
        :type: int
        """
        self._plan_hash_value = plan_hash_value

    @property
    def step_id(self):
        """
        Gets the step_id of this SqlTuningTaskSqlExecutionPlanStep.
        The identification number of a step in the SQL execution plan. This is unique within the SQL execution plan.
        This is not the `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The step_id of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: int
        """
        return self._step_id

    @step_id.setter
    def step_id(self, step_id):
        """
        Sets the step_id of this SqlTuningTaskSqlExecutionPlanStep.
        The identification number of a step in the SQL execution plan. This is unique within the SQL execution plan.
        This is not the `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param step_id: The step_id of this SqlTuningTaskSqlExecutionPlanStep.
        :type: int
        """
        self._step_id = step_id

    @property
    def parent_step_id(self):
        """
        Gets the parent_step_id of this SqlTuningTaskSqlExecutionPlanStep.
        The ID of the next step that operates on the results of this step.
        This is not the `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The parent_step_id of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: int
        """
        return self._parent_step_id

    @parent_step_id.setter
    def parent_step_id(self, parent_step_id):
        """
        Sets the parent_step_id of this SqlTuningTaskSqlExecutionPlanStep.
        The ID of the next step that operates on the results of this step.
        This is not the `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param parent_step_id: The parent_step_id of this SqlTuningTaskSqlExecutionPlanStep.
        :type: int
        """
        self._parent_step_id = parent_step_id

    @property
    def position(self):
        """
        Gets the position of this SqlTuningTaskSqlExecutionPlanStep.
        The order of processing for steps with the same parent ID.


        :return: The position of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        """
        Sets the position of this SqlTuningTaskSqlExecutionPlanStep.
        The order of processing for steps with the same parent ID.


        :param position: The position of this SqlTuningTaskSqlExecutionPlanStep.
        :type: int
        """
        self._position = position

    @property
    def operation(self):
        """
        Gets the operation of this SqlTuningTaskSqlExecutionPlanStep.
        The name of the operation performed at this step.


        :return: The operation of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """
        Sets the operation of this SqlTuningTaskSqlExecutionPlanStep.
        The name of the operation performed at this step.


        :param operation: The operation of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._operation = operation

    @property
    def options(self):
        """
        Gets the options of this SqlTuningTaskSqlExecutionPlanStep.
        The options used for the operation performed at this step.


        :return: The options of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._options

    @options.setter
    def options(self, options):
        """
        Sets the options of this SqlTuningTaskSqlExecutionPlanStep.
        The options used for the operation performed at this step.


        :param options: The options of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._options = options

    @property
    def optimizer_mode(self):
        """
        Gets the optimizer_mode of this SqlTuningTaskSqlExecutionPlanStep.
        The current mode of the optimizer, such as all_rows, first_rows_n (where n = 1, 10, 100, 1000, and so on).


        :return: The optimizer_mode of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._optimizer_mode

    @optimizer_mode.setter
    def optimizer_mode(self, optimizer_mode):
        """
        Sets the optimizer_mode of this SqlTuningTaskSqlExecutionPlanStep.
        The current mode of the optimizer, such as all_rows, first_rows_n (where n = 1, 10, 100, 1000, and so on).


        :param optimizer_mode: The optimizer_mode of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._optimizer_mode = optimizer_mode

    @property
    def cost(self):
        """
        Gets the cost of this SqlTuningTaskSqlExecutionPlanStep.
        The cost of the current operation estimated by the cost-based optimizer (CBO).


        :return: The cost of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: float
        """
        return self._cost

    @cost.setter
    def cost(self, cost):
        """
        Sets the cost of this SqlTuningTaskSqlExecutionPlanStep.
        The cost of the current operation estimated by the cost-based optimizer (CBO).


        :param cost: The cost of this SqlTuningTaskSqlExecutionPlanStep.
        :type: float
        """
        self._cost = cost

    @property
    def cardinality(self):
        """
        Gets the cardinality of this SqlTuningTaskSqlExecutionPlanStep.
        The number of rows returned by the current operation (estimated by the CBO).


        :return: The cardinality of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: int
        """
        return self._cardinality

    @cardinality.setter
    def cardinality(self, cardinality):
        """
        Sets the cardinality of this SqlTuningTaskSqlExecutionPlanStep.
        The number of rows returned by the current operation (estimated by the CBO).


        :param cardinality: The cardinality of this SqlTuningTaskSqlExecutionPlanStep.
        :type: int
        """
        self._cardinality = cardinality

    @property
    def bytes(self):
        """
        Gets the bytes of this SqlTuningTaskSqlExecutionPlanStep.
        The number of bytes returned by the current operation.


        :return: The bytes of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: int
        """
        return self._bytes

    @bytes.setter
    def bytes(self, bytes):
        """
        Sets the bytes of this SqlTuningTaskSqlExecutionPlanStep.
        The number of bytes returned by the current operation.


        :param bytes: The bytes of this SqlTuningTaskSqlExecutionPlanStep.
        :type: int
        """
        self._bytes = bytes

    @property
    def cpu_cost(self):
        """
        Gets the cpu_cost of this SqlTuningTaskSqlExecutionPlanStep.
        The CPU cost of the current operation.


        :return: The cpu_cost of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: float
        """
        return self._cpu_cost

    @cpu_cost.setter
    def cpu_cost(self, cpu_cost):
        """
        Sets the cpu_cost of this SqlTuningTaskSqlExecutionPlanStep.
        The CPU cost of the current operation.


        :param cpu_cost: The cpu_cost of this SqlTuningTaskSqlExecutionPlanStep.
        :type: float
        """
        self._cpu_cost = cpu_cost

    @property
    def io_cost(self):
        """
        Gets the io_cost of this SqlTuningTaskSqlExecutionPlanStep.
        The I/O cost of the current operation.


        :return: The io_cost of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: float
        """
        return self._io_cost

    @io_cost.setter
    def io_cost(self, io_cost):
        """
        Sets the io_cost of this SqlTuningTaskSqlExecutionPlanStep.
        The I/O cost of the current operation.


        :param io_cost: The io_cost of this SqlTuningTaskSqlExecutionPlanStep.
        :type: float
        """
        self._io_cost = io_cost

    @property
    def temp_space(self):
        """
        Gets the temp_space of this SqlTuningTaskSqlExecutionPlanStep.
        The temporary space usage (in bytes) of the operation (sort or hash-join) as estimated by the CBO.


        :return: The temp_space of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: int
        """
        return self._temp_space

    @temp_space.setter
    def temp_space(self, temp_space):
        """
        Sets the temp_space of this SqlTuningTaskSqlExecutionPlanStep.
        The temporary space usage (in bytes) of the operation (sort or hash-join) as estimated by the CBO.


        :param temp_space: The temp_space of this SqlTuningTaskSqlExecutionPlanStep.
        :type: int
        """
        self._temp_space = temp_space

    @property
    def time(self):
        """
        Gets the time of this SqlTuningTaskSqlExecutionPlanStep.
        The elapsed time (in seconds) of the operation as estimated by the CBO.


        :return: The time of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """
        Sets the time of this SqlTuningTaskSqlExecutionPlanStep.
        The elapsed time (in seconds) of the operation as estimated by the CBO.


        :param time: The time of this SqlTuningTaskSqlExecutionPlanStep.
        :type: int
        """
        self._time = time

    @property
    def object_node(self):
        """
        Gets the object_node of this SqlTuningTaskSqlExecutionPlanStep.
        The name of the database link used to reference the object.


        :return: The object_node of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._object_node

    @object_node.setter
    def object_node(self, object_node):
        """
        Sets the object_node of this SqlTuningTaskSqlExecutionPlanStep.
        The name of the database link used to reference the object.


        :param object_node: The object_node of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._object_node = object_node

    @property
    def object_owner(self):
        """
        Gets the object_owner of this SqlTuningTaskSqlExecutionPlanStep.
        The owner of the object.


        :return: The object_owner of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._object_owner

    @object_owner.setter
    def object_owner(self, object_owner):
        """
        Sets the object_owner of this SqlTuningTaskSqlExecutionPlanStep.
        The owner of the object.


        :param object_owner: The object_owner of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._object_owner = object_owner

    @property
    def object_name(self):
        """
        Gets the object_name of this SqlTuningTaskSqlExecutionPlanStep.
        The name of the object.


        :return: The object_name of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this SqlTuningTaskSqlExecutionPlanStep.
        The name of the object.


        :param object_name: The object_name of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._object_name = object_name

    @property
    def object_position(self):
        """
        Gets the object_position of this SqlTuningTaskSqlExecutionPlanStep.
        The numbered position of the object name in the original SQL statement.


        :return: The object_position of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: int
        """
        return self._object_position

    @object_position.setter
    def object_position(self, object_position):
        """
        Sets the object_position of this SqlTuningTaskSqlExecutionPlanStep.
        The numbered position of the object name in the original SQL statement.


        :param object_position: The object_position of this SqlTuningTaskSqlExecutionPlanStep.
        :type: int
        """
        self._object_position = object_position

    @property
    def object_type(self):
        """
        Gets the object_type of this SqlTuningTaskSqlExecutionPlanStep.
        The descriptive modifier that further describes the type of object.


        :return: The object_type of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """
        Sets the object_type of this SqlTuningTaskSqlExecutionPlanStep.
        The descriptive modifier that further describes the type of object.


        :param object_type: The object_type of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._object_type = object_type

    @property
    def partition_start(self):
        """
        Gets the partition_start of this SqlTuningTaskSqlExecutionPlanStep.
        A step may get data from a range of partitions of a partitioned object, such as table or index,
        based on predicates and sorting order. The partionStart is the starting partition of the range.
        The partitionStop is the ending partition of the range.


        :return: The partition_start of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._partition_start

    @partition_start.setter
    def partition_start(self, partition_start):
        """
        Sets the partition_start of this SqlTuningTaskSqlExecutionPlanStep.
        A step may get data from a range of partitions of a partitioned object, such as table or index,
        based on predicates and sorting order. The partionStart is the starting partition of the range.
        The partitionStop is the ending partition of the range.


        :param partition_start: The partition_start of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._partition_start = partition_start

    @property
    def partition_stop(self):
        """
        Gets the partition_stop of this SqlTuningTaskSqlExecutionPlanStep.
        A step may get data from a range of partitions of a partitioned object, such as table or index,
        based on predicates and sorting order. The partionStart is the starting partition of the range.
        The partitionStop is the ending partition of the range.


        :return: The partition_stop of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._partition_stop

    @partition_stop.setter
    def partition_stop(self, partition_stop):
        """
        Sets the partition_stop of this SqlTuningTaskSqlExecutionPlanStep.
        A step may get data from a range of partitions of a partitioned object, such as table or index,
        based on predicates and sorting order. The partionStart is the starting partition of the range.
        The partitionStop is the ending partition of the range.


        :param partition_stop: The partition_stop of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._partition_stop = partition_stop

    @property
    def partition_id(self):
        """
        Gets the partition_id of this SqlTuningTaskSqlExecutionPlanStep.
        The ID of the step in the execution plan that has computed the pair of values of partitionStart and partitionStop.


        :return: The partition_id of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: int
        """
        return self._partition_id

    @partition_id.setter
    def partition_id(self, partition_id):
        """
        Sets the partition_id of this SqlTuningTaskSqlExecutionPlanStep.
        The ID of the step in the execution plan that has computed the pair of values of partitionStart and partitionStop.


        :param partition_id: The partition_id of this SqlTuningTaskSqlExecutionPlanStep.
        :type: int
        """
        self._partition_id = partition_id

    @property
    def remarks(self):
        """
        Gets the remarks of this SqlTuningTaskSqlExecutionPlanStep.
        The place for comments that can be added to the steps of the execution plan.


        :return: The remarks of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._remarks

    @remarks.setter
    def remarks(self, remarks):
        """
        Sets the remarks of this SqlTuningTaskSqlExecutionPlanStep.
        The place for comments that can be added to the steps of the execution plan.


        :param remarks: The remarks of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._remarks = remarks

    @property
    def number_of_search_column(self):
        """
        Gets the number_of_search_column of this SqlTuningTaskSqlExecutionPlanStep.
        Number of index columns with start and stop keys (that is, the number of columns with matching predicates).


        :return: The number_of_search_column of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: int
        """
        return self._number_of_search_column

    @number_of_search_column.setter
    def number_of_search_column(self, number_of_search_column):
        """
        Sets the number_of_search_column of this SqlTuningTaskSqlExecutionPlanStep.
        Number of index columns with start and stop keys (that is, the number of columns with matching predicates).


        :param number_of_search_column: The number_of_search_column of this SqlTuningTaskSqlExecutionPlanStep.
        :type: int
        """
        self._number_of_search_column = number_of_search_column

    @property
    def other(self):
        """
        Gets the other of this SqlTuningTaskSqlExecutionPlanStep.
        Information about parallel execution servers and parallel queries


        :return: The other of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._other

    @other.setter
    def other(self, other):
        """
        Sets the other of this SqlTuningTaskSqlExecutionPlanStep.
        Information about parallel execution servers and parallel queries


        :param other: The other of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._other = other

    @property
    def other_tag(self):
        """
        Gets the other_tag of this SqlTuningTaskSqlExecutionPlanStep.
        Describes the function of the SQL text in the OTHER column.


        :return: The other_tag of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._other_tag

    @other_tag.setter
    def other_tag(self, other_tag):
        """
        Sets the other_tag of this SqlTuningTaskSqlExecutionPlanStep.
        Describes the function of the SQL text in the OTHER column.


        :param other_tag: The other_tag of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._other_tag = other_tag

    @property
    def attribute(self):
        """
        Gets the attribute of this SqlTuningTaskSqlExecutionPlanStep.
        The text string identifying the type of execution plan.


        :return: The attribute of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._attribute

    @attribute.setter
    def attribute(self, attribute):
        """
        Sets the attribute of this SqlTuningTaskSqlExecutionPlanStep.
        The text string identifying the type of execution plan.


        :param attribute: The attribute of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._attribute = attribute

    @property
    def access_predicates(self):
        """
        Gets the access_predicates of this SqlTuningTaskSqlExecutionPlanStep.
        The predicates used to locate rows in an access structure. For example,
        start or stop predicates for an index range scan.


        :return: The access_predicates of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._access_predicates

    @access_predicates.setter
    def access_predicates(self, access_predicates):
        """
        Sets the access_predicates of this SqlTuningTaskSqlExecutionPlanStep.
        The predicates used to locate rows in an access structure. For example,
        start or stop predicates for an index range scan.


        :param access_predicates: The access_predicates of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._access_predicates = access_predicates

    @property
    def filter_predicates(self):
        """
        Gets the filter_predicates of this SqlTuningTaskSqlExecutionPlanStep.
        The predicates used to filter rows before producing them.


        :return: The filter_predicates of this SqlTuningTaskSqlExecutionPlanStep.
        :rtype: str
        """
        return self._filter_predicates

    @filter_predicates.setter
    def filter_predicates(self, filter_predicates):
        """
        Sets the filter_predicates of this SqlTuningTaskSqlExecutionPlanStep.
        The predicates used to filter rows before producing them.


        :param filter_predicates: The filter_predicates of this SqlTuningTaskSqlExecutionPlanStep.
        :type: str
        """
        self._filter_predicates = filter_predicates

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateIngressGatewayDetails(object):
    """
    The information to be updated.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateIngressGatewayDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this UpdateIngressGatewayDetails.
        :type description: str

        :param hosts:
            The value to assign to the hosts property of this UpdateIngressGatewayDetails.
        :type hosts: list[oci.service_mesh.models.IngressGatewayHost]

        :param access_logging:
            The value to assign to the access_logging property of this UpdateIngressGatewayDetails.
        :type access_logging: oci.service_mesh.models.AccessLoggingConfiguration

        :param mtls:
            The value to assign to the mtls property of this UpdateIngressGatewayDetails.
        :type mtls: oci.service_mesh.models.CreateIngressGatewayMutualTransportLayerSecurityDetails

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateIngressGatewayDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateIngressGatewayDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'description': 'str',
            'hosts': 'list[IngressGatewayHost]',
            'access_logging': 'AccessLoggingConfiguration',
            'mtls': 'CreateIngressGatewayMutualTransportLayerSecurityDetails',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'description': 'description',
            'hosts': 'hosts',
            'access_logging': 'accessLogging',
            'mtls': 'mtls',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._description = None
        self._hosts = None
        self._access_logging = None
        self._mtls = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def description(self):
        """
        Gets the description of this UpdateIngressGatewayDetails.
        Description of the resource. It can be changed after creation.
        Avoid entering confidential information.

        Example: `This is my new resource`


        :return: The description of this UpdateIngressGatewayDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateIngressGatewayDetails.
        Description of the resource. It can be changed after creation.
        Avoid entering confidential information.

        Example: `This is my new resource`


        :param description: The description of this UpdateIngressGatewayDetails.
        :type: str
        """
        self._description = description

    @property
    def hosts(self):
        """
        Gets the hosts of this UpdateIngressGatewayDetails.
        An array of hostnames and their listener configuration that this gateway will bind to.


        :return: The hosts of this UpdateIngressGatewayDetails.
        :rtype: list[oci.service_mesh.models.IngressGatewayHost]
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """
        Sets the hosts of this UpdateIngressGatewayDetails.
        An array of hostnames and their listener configuration that this gateway will bind to.


        :param hosts: The hosts of this UpdateIngressGatewayDetails.
        :type: list[oci.service_mesh.models.IngressGatewayHost]
        """
        self._hosts = hosts

    @property
    def access_logging(self):
        """
        Gets the access_logging of this UpdateIngressGatewayDetails.

        :return: The access_logging of this UpdateIngressGatewayDetails.
        :rtype: oci.service_mesh.models.AccessLoggingConfiguration
        """
        return self._access_logging

    @access_logging.setter
    def access_logging(self, access_logging):
        """
        Sets the access_logging of this UpdateIngressGatewayDetails.

        :param access_logging: The access_logging of this UpdateIngressGatewayDetails.
        :type: oci.service_mesh.models.AccessLoggingConfiguration
        """
        self._access_logging = access_logging

    @property
    def mtls(self):
        """
        Gets the mtls of this UpdateIngressGatewayDetails.

        :return: The mtls of this UpdateIngressGatewayDetails.
        :rtype: oci.service_mesh.models.CreateIngressGatewayMutualTransportLayerSecurityDetails
        """
        return self._mtls

    @mtls.setter
    def mtls(self, mtls):
        """
        Sets the mtls of this UpdateIngressGatewayDetails.

        :param mtls: The mtls of this UpdateIngressGatewayDetails.
        :type: oci.service_mesh.models.CreateIngressGatewayMutualTransportLayerSecurityDetails
        """
        self._mtls = mtls

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateIngressGatewayDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateIngressGatewayDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateIngressGatewayDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateIngressGatewayDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateIngressGatewayDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateIngressGatewayDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateIngressGatewayDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateIngressGatewayDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Dashboard(object):
    """
    The base schema for a dashboard.
    Derived schemas have configurations and widgets specific to the  `schemaVersion`.
    """

    #: A constant which can be used with the schema_version property of a Dashboard.
    #: This constant has a value of "V1"
    SCHEMA_VERSION_V1 = "V1"

    #: A constant which can be used with the lifecycle_state property of a Dashboard.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Dashboard.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Dashboard.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Dashboard.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Dashboard.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Dashboard.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new Dashboard object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.dashboard_service.models.V1Dashboard`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Dashboard.
        :type id: str

        :param dashboard_group_id:
            The value to assign to the dashboard_group_id property of this Dashboard.
        :type dashboard_group_id: str

        :param display_name:
            The value to assign to the display_name property of this Dashboard.
        :type display_name: str

        :param description:
            The value to assign to the description property of this Dashboard.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Dashboard.
        :type compartment_id: str

        :param schema_version:
            The value to assign to the schema_version property of this Dashboard.
            Allowed values for this property are: "V1", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type schema_version: str

        :param time_created:
            The value to assign to the time_created property of this Dashboard.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Dashboard.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Dashboard.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Dashboard.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Dashboard.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this Dashboard.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'dashboard_group_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'schema_version': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'dashboard_group_id': 'dashboardGroupId',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'schema_version': 'schemaVersion',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._dashboard_group_id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._schema_version = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['schemaVersion']

        if type == 'V1':
            return 'V1Dashboard'
        else:
            return 'Dashboard'

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Dashboard.
        The `OCID`__ of the dashboard resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this Dashboard.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Dashboard.
        The `OCID`__ of the dashboard resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this Dashboard.
        :type: str
        """
        self._id = id

    @property
    def dashboard_group_id(self):
        """
        **[Required]** Gets the dashboard_group_id of this Dashboard.
        The `OCID`__ of the dashboard group that the dashboard belongs to.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The dashboard_group_id of this Dashboard.
        :rtype: str
        """
        return self._dashboard_group_id

    @dashboard_group_id.setter
    def dashboard_group_id(self, dashboard_group_id):
        """
        Sets the dashboard_group_id of this Dashboard.
        The `OCID`__ of the dashboard group that the dashboard belongs to.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param dashboard_group_id: The dashboard_group_id of this Dashboard.
        :type: str
        """
        self._dashboard_group_id = dashboard_group_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this Dashboard.
        A user-friendly name for the dashboard. Does not have to be unique, and it can be changed. Avoid entering confidential information.
        Leading and trailing spaces and the following special characters are not allowed: <>()=/'\"&\\


        :return: The display_name of this Dashboard.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Dashboard.
        A user-friendly name for the dashboard. Does not have to be unique, and it can be changed. Avoid entering confidential information.
        Leading and trailing spaces and the following special characters are not allowed: <>()=/'\"&\\


        :param display_name: The display_name of this Dashboard.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        **[Required]** Gets the description of this Dashboard.
        A short description of the dashboard. It can be changed. Avoid entering confidential information.
        The following special characters are not allowed: <>()=/'\"&\\


        :return: The description of this Dashboard.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Dashboard.
        A short description of the dashboard. It can be changed. Avoid entering confidential information.
        The following special characters are not allowed: <>()=/'\"&\\


        :param description: The description of this Dashboard.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Dashboard.
        The `OCID`__ of the compartment containing the dashboard. A dashboard is always in the same compartment as its dashboard group.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this Dashboard.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Dashboard.
        The `OCID`__ of the compartment containing the dashboard. A dashboard is always in the same compartment as its dashboard group.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this Dashboard.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def schema_version(self):
        """
        **[Required]** Gets the schema_version of this Dashboard.
        The schema describing how to interpret the dashboard configuration and widgets.

        Allowed values for this property are: "V1", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The schema_version of this Dashboard.
        :rtype: str
        """
        return self._schema_version

    @schema_version.setter
    def schema_version(self, schema_version):
        """
        Sets the schema_version of this Dashboard.
        The schema describing how to interpret the dashboard configuration and widgets.


        :param schema_version: The schema_version of this Dashboard.
        :type: str
        """
        allowed_values = ["V1"]
        if not value_allowed_none_or_none_sentinel(schema_version, allowed_values):
            schema_version = 'UNKNOWN_ENUM_VALUE'
        self._schema_version = schema_version

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Dashboard.
        The date and time the dashboard was created, in the format defined by `RFC3339`__.

         Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Dashboard.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Dashboard.
        The date and time the dashboard was created, in the format defined by `RFC3339`__.

         Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Dashboard.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this Dashboard.
        The date and time the dashboard was updated, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this Dashboard.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Dashboard.
        The date and time the dashboard was updated, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this Dashboard.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Dashboard.
        The current state of the dashboard.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Dashboard.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Dashboard.
        The current state of the dashboard.


        :param lifecycle_state: The lifecycle_state of this Dashboard.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        **[Required]** Gets the freeform_tags of this Dashboard.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this Dashboard.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Dashboard.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this Dashboard.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        **[Required]** Gets the defined_tags of this Dashboard.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this Dashboard.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Dashboard.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this Dashboard.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this Dashboard.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this Dashboard.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this Dashboard.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this Dashboard.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Product(object):
    """
    Details of product.
    """

    #: A constant which can be used with the category property of a Product.
    #: This constant has a value of "BASE"
    CATEGORY_BASE = "BASE"

    #: A constant which can be used with the category property of a Product.
    #: This constant has a value of "OPTION"
    CATEGORY_OPTION = "OPTION"

    def __init__(self, **kwargs):
        """
        Initializes a new Product object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Product.
        :type name: str

        :param count:
            The value to assign to the count property of this Product.
        :type count: float

        :param category:
            The value to assign to the category property of this Product.
            Allowed values for this property are: "BASE", "OPTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type category: str

        """
        self.swagger_types = {
            'name': 'str',
            'count': 'float',
            'category': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'count': 'count',
            'category': 'category'
        }

        self._name = None
        self._count = None
        self._category = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Product.
        Name of the product.


        :return: The name of this Product.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Product.
        Name of the product.


        :param name: The name of this Product.
        :type: str
        """
        self._name = name

    @property
    def count(self):
        """
        **[Required]** Gets the count of this Product.
        Units required for the missing product.


        :return: The count of this Product.
        :rtype: float
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this Product.
        Units required for the missing product.


        :param count: The count of this Product.
        :type: float
        """
        self._count = count

    @property
    def category(self):
        """
        **[Required]** Gets the category of this Product.
        Product category base or option.

        Allowed values for this property are: "BASE", "OPTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The category of this Product.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this Product.
        Product category base or option.


        :param category: The category of this Product.
        :type: str
        """
        allowed_values = ["BASE", "OPTION"]
        if not value_allowed_none_or_none_sentinel(category, allowed_values):
            category = 'UNKNOWN_ENUM_VALUE'
        self._category = category

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ThinAssociationAuthorizationResponse(object):
    """
    ThinAssociationAuthorizationResponse model.
    """

    #: A constant which can be used with the association_result property of a ThinAssociationAuthorizationResponse.
    #: This constant has a value of "FAIL_UNKNOWN"
    ASSOCIATION_RESULT_FAIL_UNKNOWN = "FAIL_UNKNOWN"

    #: A constant which can be used with the association_result property of a ThinAssociationAuthorizationResponse.
    #: This constant has a value of "FAIL_BAD_REQUEST"
    ASSOCIATION_RESULT_FAIL_BAD_REQUEST = "FAIL_BAD_REQUEST"

    #: A constant which can be used with the association_result property of a ThinAssociationAuthorizationResponse.
    #: This constant has a value of "FAIL_MISSING_ENDORSE"
    ASSOCIATION_RESULT_FAIL_MISSING_ENDORSE = "FAIL_MISSING_ENDORSE"

    #: A constant which can be used with the association_result property of a ThinAssociationAuthorizationResponse.
    #: This constant has a value of "FAIL_MISSING_ADMIT"
    ASSOCIATION_RESULT_FAIL_MISSING_ADMIT = "FAIL_MISSING_ADMIT"

    #: A constant which can be used with the association_result property of a ThinAssociationAuthorizationResponse.
    #: This constant has a value of "SUCCESS"
    ASSOCIATION_RESULT_SUCCESS = "SUCCESS"

    def __init__(self, **kwargs):
        """
        Initializes a new ThinAssociationAuthorizationResponse object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param responses:
            The value to assign to the responses property of this ThinAssociationAuthorizationResponse.
        :type responses: list[oci.identity_data_plane.models.ThinAuthorizationResponse]

        :param association_result:
            The value to assign to the association_result property of this ThinAssociationAuthorizationResponse.
            Allowed values for this property are: "FAIL_UNKNOWN", "FAIL_BAD_REQUEST", "FAIL_MISSING_ENDORSE", "FAIL_MISSING_ADMIT", "SUCCESS"
        :type association_result: str

        :param decision_cache_duration:
            The value to assign to the decision_cache_duration property of this ThinAssociationAuthorizationResponse.
        :type decision_cache_duration: str

        """
        self.swagger_types = {
            'responses': 'list[ThinAuthorizationResponse]',
            'association_result': 'str',
            'decision_cache_duration': 'str'
        }

        self.attribute_map = {
            'responses': 'responses',
            'association_result': 'associationResult',
            'decision_cache_duration': 'decisionCacheDuration'
        }

        self._responses = None
        self._association_result = None
        self._decision_cache_duration = None

    @property
    def responses(self):
        """
        **[Required]** Gets the responses of this ThinAssociationAuthorizationResponse.
        The authorization responses.


        :return: The responses of this ThinAssociationAuthorizationResponse.
        :rtype: list[oci.identity_data_plane.models.ThinAuthorizationResponse]
        """
        return self._responses

    @responses.setter
    def responses(self, responses):
        """
        Sets the responses of this ThinAssociationAuthorizationResponse.
        The authorization responses.


        :param responses: The responses of this ThinAssociationAuthorizationResponse.
        :type: list[oci.identity_data_plane.models.ThinAuthorizationResponse]
        """
        self._responses = responses

    @property
    def association_result(self):
        """
        **[Required]** Gets the association_result of this ThinAssociationAuthorizationResponse.
        The association verification result.

        Allowed values for this property are: "FAIL_UNKNOWN", "FAIL_BAD_REQUEST", "FAIL_MISSING_ENDORSE", "FAIL_MISSING_ADMIT", "SUCCESS"


        :return: The association_result of this ThinAssociationAuthorizationResponse.
        :rtype: str
        """
        return self._association_result

    @association_result.setter
    def association_result(self, association_result):
        """
        Sets the association_result of this ThinAssociationAuthorizationResponse.
        The association verification result.


        :param association_result: The association_result of this ThinAssociationAuthorizationResponse.
        :type: str
        """
        allowed_values = ["FAIL_UNKNOWN", "FAIL_BAD_REQUEST", "FAIL_MISSING_ENDORSE", "FAIL_MISSING_ADMIT", "SUCCESS"]
        if not value_allowed_none_or_none_sentinel(association_result, allowed_values):
            raise ValueError(
                "Invalid value for `association_result`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._association_result = association_result

    @property
    def decision_cache_duration(self):
        """
        Gets the decision_cache_duration of this ThinAssociationAuthorizationResponse.
        The decision cache duration.


        :return: The decision_cache_duration of this ThinAssociationAuthorizationResponse.
        :rtype: str
        """
        return self._decision_cache_duration

    @decision_cache_duration.setter
    def decision_cache_duration(self, decision_cache_duration):
        """
        Sets the decision_cache_duration of this ThinAssociationAuthorizationResponse.
        The decision cache duration.


        :param decision_cache_duration: The decision_cache_duration of this ThinAssociationAuthorizationResponse.
        :type: str
        """
        self._decision_cache_duration = decision_cache_duration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_channel_details import CreateChannelDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateApplicationChannelDetails(CreateChannelDetails):
    """
    Properties required to create an Application channel.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateApplicationChannelDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.oda.models.CreateApplicationChannelDetails.type` attribute
        of this class is ``APPLICATION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this CreateApplicationChannelDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateApplicationChannelDetails.
        :type description: str

        :param type:
            The value to assign to the type property of this CreateApplicationChannelDetails.
            Allowed values for this property are: "ANDROID", "APPEVENT", "APPLICATION", "CORTANA", "FACEBOOK", "IOS", "MSTEAMS", "OSS", "OSVC", "SERVICECLOUD", "SLACK", "TEST", "TWILIO", "WEB", "WEBHOOK"
        :type type: str

        :param session_expiry_duration_in_milliseconds:
            The value to assign to the session_expiry_duration_in_milliseconds property of this CreateApplicationChannelDetails.
        :type session_expiry_duration_in_milliseconds: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateApplicationChannelDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateApplicationChannelDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param outbound_url:
            The value to assign to the outbound_url property of this CreateApplicationChannelDetails.
        :type outbound_url: str

        :param is_authenticated_user_id:
            The value to assign to the is_authenticated_user_id property of this CreateApplicationChannelDetails.
        :type is_authenticated_user_id: bool

        """
        self.swagger_types = {
            'name': 'str',
            'description': 'str',
            'type': 'str',
            'session_expiry_duration_in_milliseconds': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'outbound_url': 'str',
            'is_authenticated_user_id': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'description': 'description',
            'type': 'type',
            'session_expiry_duration_in_milliseconds': 'sessionExpiryDurationInMilliseconds',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'outbound_url': 'outboundUrl',
            'is_authenticated_user_id': 'isAuthenticatedUserId'
        }

        self._name = None
        self._description = None
        self._type = None
        self._session_expiry_duration_in_milliseconds = None
        self._freeform_tags = None
        self._defined_tags = None
        self._outbound_url = None
        self._is_authenticated_user_id = None
        self._type = 'APPLICATION'

    @property
    def outbound_url(self):
        """
        Gets the outbound_url of this CreateApplicationChannelDetails.
        The URL to send response and error messages to.


        :return: The outbound_url of this CreateApplicationChannelDetails.
        :rtype: str
        """
        return self._outbound_url

    @outbound_url.setter
    def outbound_url(self, outbound_url):
        """
        Sets the outbound_url of this CreateApplicationChannelDetails.
        The URL to send response and error messages to.


        :param outbound_url: The outbound_url of this CreateApplicationChannelDetails.
        :type: str
        """
        self._outbound_url = outbound_url

    @property
    def is_authenticated_user_id(self):
        """
        **[Required]** Gets the is_authenticated_user_id of this CreateApplicationChannelDetails.
        True if the user id in the AIC message should be treated as an authenticated user id.


        :return: The is_authenticated_user_id of this CreateApplicationChannelDetails.
        :rtype: bool
        """
        return self._is_authenticated_user_id

    @is_authenticated_user_id.setter
    def is_authenticated_user_id(self, is_authenticated_user_id):
        """
        Sets the is_authenticated_user_id of this CreateApplicationChannelDetails.
        True if the user id in the AIC message should be treated as an authenticated user id.


        :param is_authenticated_user_id: The is_authenticated_user_id of this CreateApplicationChannelDetails.
        :type: bool
        """
        self._is_authenticated_user_id = is_authenticated_user_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AddmTaskSummary(object):
    """
    The object containing the ADDM task metadata.
    """

    #: A constant which can be used with the status property of a AddmTaskSummary.
    #: This constant has a value of "INITIAL"
    STATUS_INITIAL = "INITIAL"

    #: A constant which can be used with the status property of a AddmTaskSummary.
    #: This constant has a value of "EXECUTING"
    STATUS_EXECUTING = "EXECUTING"

    #: A constant which can be used with the status property of a AddmTaskSummary.
    #: This constant has a value of "INTERRUPTED"
    STATUS_INTERRUPTED = "INTERRUPTED"

    #: A constant which can be used with the status property of a AddmTaskSummary.
    #: This constant has a value of "COMPLETED"
    STATUS_COMPLETED = "COMPLETED"

    #: A constant which can be used with the status property of a AddmTaskSummary.
    #: This constant has a value of "ERROR"
    STATUS_ERROR = "ERROR"

    #: A constant which can be used with the how_created property of a AddmTaskSummary.
    #: This constant has a value of "AUTO"
    HOW_CREATED_AUTO = "AUTO"

    #: A constant which can be used with the how_created property of a AddmTaskSummary.
    #: This constant has a value of "MANUAL"
    HOW_CREATED_MANUAL = "MANUAL"

    def __init__(self, **kwargs):
        """
        Initializes a new AddmTaskSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param task_name:
            The value to assign to the task_name property of this AddmTaskSummary.
        :type task_name: str

        :param task_id:
            The value to assign to the task_id property of this AddmTaskSummary.
        :type task_id: int

        :param description:
            The value to assign to the description property of this AddmTaskSummary.
        :type description: str

        :param db_user:
            The value to assign to the db_user property of this AddmTaskSummary.
        :type db_user: str

        :param status:
            The value to assign to the status property of this AddmTaskSummary.
            Allowed values for this property are: "INITIAL", "EXECUTING", "INTERRUPTED", "COMPLETED", "ERROR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param time_created:
            The value to assign to the time_created property of this AddmTaskSummary.
        :type time_created: datetime

        :param how_created:
            The value to assign to the how_created property of this AddmTaskSummary.
            Allowed values for this property are: "AUTO", "MANUAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type how_created: str

        :param start_snapshot_time:
            The value to assign to the start_snapshot_time property of this AddmTaskSummary.
        :type start_snapshot_time: datetime

        :param end_snapshot_time:
            The value to assign to the end_snapshot_time property of this AddmTaskSummary.
        :type end_snapshot_time: datetime

        :param begin_snapshot_id:
            The value to assign to the begin_snapshot_id property of this AddmTaskSummary.
        :type begin_snapshot_id: int

        :param end_snapshot_id:
            The value to assign to the end_snapshot_id property of this AddmTaskSummary.
        :type end_snapshot_id: int

        :param findings:
            The value to assign to the findings property of this AddmTaskSummary.
        :type findings: int

        """
        self.swagger_types = {
            'task_name': 'str',
            'task_id': 'int',
            'description': 'str',
            'db_user': 'str',
            'status': 'str',
            'time_created': 'datetime',
            'how_created': 'str',
            'start_snapshot_time': 'datetime',
            'end_snapshot_time': 'datetime',
            'begin_snapshot_id': 'int',
            'end_snapshot_id': 'int',
            'findings': 'int'
        }

        self.attribute_map = {
            'task_name': 'taskName',
            'task_id': 'taskId',
            'description': 'description',
            'db_user': 'dbUser',
            'status': 'status',
            'time_created': 'timeCreated',
            'how_created': 'howCreated',
            'start_snapshot_time': 'startSnapshotTime',
            'end_snapshot_time': 'endSnapshotTime',
            'begin_snapshot_id': 'beginSnapshotId',
            'end_snapshot_id': 'endSnapshotId',
            'findings': 'findings'
        }

        self._task_name = None
        self._task_id = None
        self._description = None
        self._db_user = None
        self._status = None
        self._time_created = None
        self._how_created = None
        self._start_snapshot_time = None
        self._end_snapshot_time = None
        self._begin_snapshot_id = None
        self._end_snapshot_id = None
        self._findings = None

    @property
    def task_name(self):
        """
        Gets the task_name of this AddmTaskSummary.
        The name of the ADDM task.


        :return: The task_name of this AddmTaskSummary.
        :rtype: str
        """
        return self._task_name

    @task_name.setter
    def task_name(self, task_name):
        """
        Sets the task_name of this AddmTaskSummary.
        The name of the ADDM task.


        :param task_name: The task_name of this AddmTaskSummary.
        :type: str
        """
        self._task_name = task_name

    @property
    def task_id(self):
        """
        **[Required]** Gets the task_id of this AddmTaskSummary.
        The ID number of the ADDM task.


        :return: The task_id of this AddmTaskSummary.
        :rtype: int
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """
        Sets the task_id of this AddmTaskSummary.
        The ID number of the ADDM task.


        :param task_id: The task_id of this AddmTaskSummary.
        :type: int
        """
        self._task_id = task_id

    @property
    def description(self):
        """
        Gets the description of this AddmTaskSummary.
        The description of the ADDM task.


        :return: The description of this AddmTaskSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this AddmTaskSummary.
        The description of the ADDM task.


        :param description: The description of this AddmTaskSummary.
        :type: str
        """
        self._description = description

    @property
    def db_user(self):
        """
        Gets the db_user of this AddmTaskSummary.
        The database user who owns the ADDM task.


        :return: The db_user of this AddmTaskSummary.
        :rtype: str
        """
        return self._db_user

    @db_user.setter
    def db_user(self, db_user):
        """
        Sets the db_user of this AddmTaskSummary.
        The database user who owns the ADDM task.


        :param db_user: The db_user of this AddmTaskSummary.
        :type: str
        """
        self._db_user = db_user

    @property
    def status(self):
        """
        Gets the status of this AddmTaskSummary.
        The status of the ADDM task.

        Allowed values for this property are: "INITIAL", "EXECUTING", "INTERRUPTED", "COMPLETED", "ERROR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this AddmTaskSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this AddmTaskSummary.
        The status of the ADDM task.


        :param status: The status of this AddmTaskSummary.
        :type: str
        """
        allowed_values = ["INITIAL", "EXECUTING", "INTERRUPTED", "COMPLETED", "ERROR"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this AddmTaskSummary.
        The creation date of the ADDM task.


        :return: The time_created of this AddmTaskSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this AddmTaskSummary.
        The creation date of the ADDM task.


        :param time_created: The time_created of this AddmTaskSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def how_created(self):
        """
        Gets the how_created of this AddmTaskSummary.
        A description of how the task was created.

        Allowed values for this property are: "AUTO", "MANUAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The how_created of this AddmTaskSummary.
        :rtype: str
        """
        return self._how_created

    @how_created.setter
    def how_created(self, how_created):
        """
        Sets the how_created of this AddmTaskSummary.
        A description of how the task was created.


        :param how_created: The how_created of this AddmTaskSummary.
        :type: str
        """
        allowed_values = ["AUTO", "MANUAL"]
        if not value_allowed_none_or_none_sentinel(how_created, allowed_values):
            how_created = 'UNKNOWN_ENUM_VALUE'
        self._how_created = how_created

    @property
    def start_snapshot_time(self):
        """
        Gets the start_snapshot_time of this AddmTaskSummary.
        The timestamp of the beginning AWR snapshot used in the ADDM task as defined by date-time RFC3339 format.


        :return: The start_snapshot_time of this AddmTaskSummary.
        :rtype: datetime
        """
        return self._start_snapshot_time

    @start_snapshot_time.setter
    def start_snapshot_time(self, start_snapshot_time):
        """
        Sets the start_snapshot_time of this AddmTaskSummary.
        The timestamp of the beginning AWR snapshot used in the ADDM task as defined by date-time RFC3339 format.


        :param start_snapshot_time: The start_snapshot_time of this AddmTaskSummary.
        :type: datetime
        """
        self._start_snapshot_time = start_snapshot_time

    @property
    def end_snapshot_time(self):
        """
        Gets the end_snapshot_time of this AddmTaskSummary.
        The timestamp of the ending AWR snapshot used in the ADDM task as defined by date-time RFC3339 format.


        :return: The end_snapshot_time of this AddmTaskSummary.
        :rtype: datetime
        """
        return self._end_snapshot_time

    @end_snapshot_time.setter
    def end_snapshot_time(self, end_snapshot_time):
        """
        Sets the end_snapshot_time of this AddmTaskSummary.
        The timestamp of the ending AWR snapshot used in the ADDM task as defined by date-time RFC3339 format.


        :param end_snapshot_time: The end_snapshot_time of this AddmTaskSummary.
        :type: datetime
        """
        self._end_snapshot_time = end_snapshot_time

    @property
    def begin_snapshot_id(self):
        """
        Gets the begin_snapshot_id of this AddmTaskSummary.
        The ID number of the beginning AWR snapshot.


        :return: The begin_snapshot_id of this AddmTaskSummary.
        :rtype: int
        """
        return self._begin_snapshot_id

    @begin_snapshot_id.setter
    def begin_snapshot_id(self, begin_snapshot_id):
        """
        Sets the begin_snapshot_id of this AddmTaskSummary.
        The ID number of the beginning AWR snapshot.


        :param begin_snapshot_id: The begin_snapshot_id of this AddmTaskSummary.
        :type: int
        """
        self._begin_snapshot_id = begin_snapshot_id

    @property
    def end_snapshot_id(self):
        """
        Gets the end_snapshot_id of this AddmTaskSummary.
        The ID number of the ending AWR snapshot.


        :return: The end_snapshot_id of this AddmTaskSummary.
        :rtype: int
        """
        return self._end_snapshot_id

    @end_snapshot_id.setter
    def end_snapshot_id(self, end_snapshot_id):
        """
        Sets the end_snapshot_id of this AddmTaskSummary.
        The ID number of the ending AWR snapshot.


        :param end_snapshot_id: The end_snapshot_id of this AddmTaskSummary.
        :type: int
        """
        self._end_snapshot_id = end_snapshot_id

    @property
    def findings(self):
        """
        Gets the findings of this AddmTaskSummary.
        The number of ADDM findings.


        :return: The findings of this AddmTaskSummary.
        :rtype: int
        """
        return self._findings

    @findings.setter
    def findings(self, findings):
        """
        Sets the findings of this AddmTaskSummary.
        The number of ADDM findings.


        :param findings: The findings of this AddmTaskSummary.
        :type: int
        """
        self._findings = findings

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryDataObjectResultSetColumnMetadata(object):
    """
    Metadata of a column in a data object query result set.
    """

    #: A constant which can be used with the data_type_name property of a QueryDataObjectResultSetColumnMetadata.
    #: This constant has a value of "NUMBER"
    DATA_TYPE_NAME_NUMBER = "NUMBER"

    #: A constant which can be used with the data_type_name property of a QueryDataObjectResultSetColumnMetadata.
    #: This constant has a value of "TIMESTAMP"
    DATA_TYPE_NAME_TIMESTAMP = "TIMESTAMP"

    #: A constant which can be used with the data_type_name property of a QueryDataObjectResultSetColumnMetadata.
    #: This constant has a value of "VARCHAR2"
    DATA_TYPE_NAME_VARCHAR2 = "VARCHAR2"

    def __init__(self, **kwargs):
        """
        Initializes a new QueryDataObjectResultSetColumnMetadata object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this QueryDataObjectResultSetColumnMetadata.
        :type name: str

        :param data_type_name:
            The value to assign to the data_type_name property of this QueryDataObjectResultSetColumnMetadata.
            Allowed values for this property are: "NUMBER", "TIMESTAMP", "VARCHAR2", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type data_type_name: str

        """
        self.swagger_types = {
            'name': 'str',
            'data_type_name': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'data_type_name': 'dataTypeName'
        }

        self._name = None
        self._data_type_name = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this QueryDataObjectResultSetColumnMetadata.
        Name of the column in a data object query result set.


        :return: The name of this QueryDataObjectResultSetColumnMetadata.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this QueryDataObjectResultSetColumnMetadata.
        Name of the column in a data object query result set.


        :param name: The name of this QueryDataObjectResultSetColumnMetadata.
        :type: str
        """
        self._name = name

    @property
    def data_type_name(self):
        """
        Gets the data_type_name of this QueryDataObjectResultSetColumnMetadata.
        Type of the column in a data object query result set.

        Allowed values for this property are: "NUMBER", "TIMESTAMP", "VARCHAR2", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The data_type_name of this QueryDataObjectResultSetColumnMetadata.
        :rtype: str
        """
        return self._data_type_name

    @data_type_name.setter
    def data_type_name(self, data_type_name):
        """
        Sets the data_type_name of this QueryDataObjectResultSetColumnMetadata.
        Type of the column in a data object query result set.


        :param data_type_name: The data_type_name of this QueryDataObjectResultSetColumnMetadata.
        :type: str
        """
        allowed_values = ["NUMBER", "TIMESTAMP", "VARCHAR2"]
        if not value_allowed_none_or_none_sentinel(data_type_name, allowed_values):
            data_type_name = 'UNKNOWN_ENUM_VALUE'
        self._data_type_name = data_type_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TagDefault(object):
    """
    Tag defaults let you specify a default tag (tagnamespace.tag=\"value\") to apply to all resource types
    in a specified compartment. The tag default is applied at the time the resource is created. Resources
    that exist in the compartment before you create the tag default are not tagged.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TagDefault object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param tag_name:
            The value to assign to the tag_name property of this TagDefault.
        :type tag_name: str

        :param value:
            The value to assign to the value property of this TagDefault.
        :type value: str

        :param is_required:
            The value to assign to the is_required property of this TagDefault.
        :type is_required: bool

        """
        self.swagger_types = {
            'tag_name': 'str',
            'value': 'str',
            'is_required': 'bool'
        }

        self.attribute_map = {
            'tag_name': 'tagName',
            'value': 'value',
            'is_required': 'isRequired'
        }

        self._tag_name = None
        self._value = None
        self._is_required = None

    @property
    def tag_name(self):
        """
        **[Required]** Gets the tag_name of this TagDefault.
        The name of the tag. The tag default will always assign a default value for this tag name.


        :return: The tag_name of this TagDefault.
        :rtype: str
        """
        return self._tag_name

    @tag_name.setter
    def tag_name(self, tag_name):
        """
        Sets the tag_name of this TagDefault.
        The name of the tag. The tag default will always assign a default value for this tag name.


        :param tag_name: The tag_name of this TagDefault.
        :type: str
        """
        self._tag_name = tag_name

    @property
    def value(self):
        """
        **[Required]** Gets the value of this TagDefault.
        The default value for the tag name. This will be applied to all new resources created in the compartment.


        :return: The value of this TagDefault.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this TagDefault.
        The default value for the tag name. This will be applied to all new resources created in the compartment.


        :param value: The value of this TagDefault.
        :type: str
        """
        self._value = value

    @property
    def is_required(self):
        """
        **[Required]** Gets the is_required of this TagDefault.
        If you specify that a value is required, a value is set during resource creation (either by
        the user creating the resource or another tag default). If no value is set, resource
        creation is blocked.

        * If the `isRequired` flag is set to \"true\", the value is set during resource creation.
        * If the `isRequired` flag is set to \"false\", the value you enter is set during resource creation.

        Example: `false`


        :return: The is_required of this TagDefault.
        :rtype: bool
        """
        return self._is_required

    @is_required.setter
    def is_required(self, is_required):
        """
        Sets the is_required of this TagDefault.
        If you specify that a value is required, a value is set during resource creation (either by
        the user creating the resource or another tag default). If no value is set, resource
        creation is blocked.

        * If the `isRequired` flag is set to \"true\", the value is set during resource creation.
        * If the `isRequired` flag is set to \"false\", the value you enter is set during resource creation.

        Example: `false`


        :param is_required: The is_required of this TagDefault.
        :type: bool
        """
        self._is_required = is_required

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SchemaSummary(object):
    """
    Details of a schema fetched from the database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SchemaSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param schema_name:
            The value to assign to the schema_name property of this SchemaSummary.
        :type schema_name: str

        :param is_oracle_maintained:
            The value to assign to the is_oracle_maintained property of this SchemaSummary.
        :type is_oracle_maintained: bool

        """
        self.swagger_types = {
            'schema_name': 'str',
            'is_oracle_maintained': 'bool'
        }

        self.attribute_map = {
            'schema_name': 'schemaName',
            'is_oracle_maintained': 'isOracleMaintained'
        }

        self._schema_name = None
        self._is_oracle_maintained = None

    @property
    def schema_name(self):
        """
        **[Required]** Gets the schema_name of this SchemaSummary.
        Name of the schema.


        :return: The schema_name of this SchemaSummary.
        :rtype: str
        """
        return self._schema_name

    @schema_name.setter
    def schema_name(self, schema_name):
        """
        Sets the schema_name of this SchemaSummary.
        Name of the schema.


        :param schema_name: The schema_name of this SchemaSummary.
        :type: str
        """
        self._schema_name = schema_name

    @property
    def is_oracle_maintained(self):
        """
        **[Required]** Gets the is_oracle_maintained of this SchemaSummary.
        Indicates if the schema is oracle supplied.


        :return: The is_oracle_maintained of this SchemaSummary.
        :rtype: bool
        """
        return self._is_oracle_maintained

    @is_oracle_maintained.setter
    def is_oracle_maintained(self, is_oracle_maintained):
        """
        Sets the is_oracle_maintained of this SchemaSummary.
        Indicates if the schema is oracle supplied.


        :param is_oracle_maintained: The is_oracle_maintained of this SchemaSummary.
        :type: bool
        """
        self._is_oracle_maintained = is_oracle_maintained

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsEntityTopologySummary(object):
    """
    Log Analytics Entity topology that contains a set of log analytics entities and a set of relationships between those.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsEntityTopologySummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param nodes:
            The value to assign to the nodes property of this LogAnalyticsEntityTopologySummary.
        :type nodes: oci.log_analytics.models.LogAnalyticsEntityCollection

        :param links:
            The value to assign to the links property of this LogAnalyticsEntityTopologySummary.
        :type links: oci.log_analytics.models.LogAnalyticsEntityTopologyLinkCollection

        """
        self.swagger_types = {
            'nodes': 'LogAnalyticsEntityCollection',
            'links': 'LogAnalyticsEntityTopologyLinkCollection'
        }

        self.attribute_map = {
            'nodes': 'nodes',
            'links': 'links'
        }

        self._nodes = None
        self._links = None

    @property
    def nodes(self):
        """
        **[Required]** Gets the nodes of this LogAnalyticsEntityTopologySummary.

        :return: The nodes of this LogAnalyticsEntityTopologySummary.
        :rtype: oci.log_analytics.models.LogAnalyticsEntityCollection
        """
        return self._nodes

    @nodes.setter
    def nodes(self, nodes):
        """
        Sets the nodes of this LogAnalyticsEntityTopologySummary.

        :param nodes: The nodes of this LogAnalyticsEntityTopologySummary.
        :type: oci.log_analytics.models.LogAnalyticsEntityCollection
        """
        self._nodes = nodes

    @property
    def links(self):
        """
        **[Required]** Gets the links of this LogAnalyticsEntityTopologySummary.

        :return: The links of this LogAnalyticsEntityTopologySummary.
        :rtype: oci.log_analytics.models.LogAnalyticsEntityTopologyLinkCollection
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this LogAnalyticsEntityTopologySummary.

        :param links: The links of this LogAnalyticsEntityTopologySummary.
        :type: oci.log_analytics.models.LogAnalyticsEntityTopologyLinkCollection
        """
        self._links = links

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .cluster_pod_network_option_details import ClusterPodNetworkOptionDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FlannelOverlayClusterPodNetworkOptionDetails(ClusterPodNetworkOptionDetails):
    """
    Network options specific to using the flannel (FLANNEL_OVERLAY) CNI
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FlannelOverlayClusterPodNetworkOptionDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.container_engine.models.FlannelOverlayClusterPodNetworkOptionDetails.cni_type` attribute
        of this class is ``FLANNEL_OVERLAY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cni_type:
            The value to assign to the cni_type property of this FlannelOverlayClusterPodNetworkOptionDetails.
            Allowed values for this property are: "OCI_VCN_IP_NATIVE", "FLANNEL_OVERLAY"
        :type cni_type: str

        """
        self.swagger_types = {
            'cni_type': 'str'
        }

        self.attribute_map = {
            'cni_type': 'cniType'
        }

        self._cni_type = None
        self._cni_type = 'FLANNEL_OVERLAY'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import


from .api_gateway_client import ApiGatewayClient
from .api_gateway_client_composite_operations import ApiGatewayClientCompositeOperations
from .deployment_client import DeploymentClient
from .deployment_client_composite_operations import DeploymentClientCompositeOperations
from .gateway_client import GatewayClient
from .gateway_client_composite_operations import GatewayClientCompositeOperations
from .subscribers_client import SubscribersClient
from .subscribers_client_composite_operations import SubscribersClientCompositeOperations
from .usage_plans_client import UsagePlansClient
from .usage_plans_client_composite_operations import UsagePlansClientCompositeOperations
from .work_requests_client import WorkRequestsClient
from .work_requests_client_composite_operations import WorkRequestsClientCompositeOperations
from . import models

__all__ = ["ApiGatewayClient", "ApiGatewayClientCompositeOperations", "DeploymentClient", "DeploymentClientCompositeOperations", "GatewayClient", "GatewayClientCompositeOperations", "SubscribersClient", "SubscribersClientCompositeOperations", "UsagePlansClient", "UsagePlansClientCompositeOperations", "WorkRequestsClient", "WorkRequestsClientCompositeOperations", "models"]



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .forwarded_routing_configuration import ForwardedRoutingConfiguration
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DrgRoutingConfiguration(ForwardedRoutingConfiguration):
    """
    Identifies the DRG route table and rule that allowed the traffic to be forwarded.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DrgRoutingConfiguration object with values from keyword arguments. The default value of the :py:attr:`~oci.vn_monitoring.models.DrgRoutingConfiguration.type` attribute
        of this class is ``DRG`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this DrgRoutingConfiguration.
            Allowed values for this property are: "VCN", "DRG"
        :type type: str

        :param drg_route_table_id:
            The value to assign to the drg_route_table_id property of this DrgRoutingConfiguration.
        :type drg_route_table_id: str

        :param route_rule:
            The value to assign to the route_rule property of this DrgRoutingConfiguration.
        :type route_rule: oci.vn_monitoring.models.DrgRouteRule

        """
        self.swagger_types = {
            'type': 'str',
            'drg_route_table_id': 'str',
            'route_rule': 'DrgRouteRule'
        }

        self.attribute_map = {
            'type': 'type',
            'drg_route_table_id': 'drgRouteTableId',
            'route_rule': 'routeRule'
        }

        self._type = None
        self._drg_route_table_id = None
        self._route_rule = None
        self._type = 'DRG'

    @property
    def drg_route_table_id(self):
        """
        **[Required]** Gets the drg_route_table_id of this DrgRoutingConfiguration.
        The `OCID`__ of the DRG route
        table that allowed the traffic.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The drg_route_table_id of this DrgRoutingConfiguration.
        :rtype: str
        """
        return self._drg_route_table_id

    @drg_route_table_id.setter
    def drg_route_table_id(self, drg_route_table_id):
        """
        Sets the drg_route_table_id of this DrgRoutingConfiguration.
        The `OCID`__ of the DRG route
        table that allowed the traffic.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param drg_route_table_id: The drg_route_table_id of this DrgRoutingConfiguration.
        :type: str
        """
        self._drg_route_table_id = drg_route_table_id

    @property
    def route_rule(self):
        """
        **[Required]** Gets the route_rule of this DrgRoutingConfiguration.

        :return: The route_rule of this DrgRoutingConfiguration.
        :rtype: oci.vn_monitoring.models.DrgRouteRule
        """
        return self._route_rule

    @route_rule.setter
    def route_rule(self, route_rule):
        """
        Sets the route_rule of this DrgRoutingConfiguration.

        :param route_rule: The route_rule of this DrgRoutingConfiguration.
        :type: oci.vn_monitoring.models.DrgRouteRule
        """
        self._route_rule = route_rule

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RequestRateLimitingConfiguration(object):
    """
    Rate limiting configuration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RequestRateLimitingConfiguration object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param period_in_seconds:
            The value to assign to the period_in_seconds property of this RequestRateLimitingConfiguration.
        :type period_in_seconds: int

        :param requests_limit:
            The value to assign to the requests_limit property of this RequestRateLimitingConfiguration.
        :type requests_limit: int

        :param action_duration_in_seconds:
            The value to assign to the action_duration_in_seconds property of this RequestRateLimitingConfiguration.
        :type action_duration_in_seconds: int

        """
        self.swagger_types = {
            'period_in_seconds': 'int',
            'requests_limit': 'int',
            'action_duration_in_seconds': 'int'
        }

        self.attribute_map = {
            'period_in_seconds': 'periodInSeconds',
            'requests_limit': 'requestsLimit',
            'action_duration_in_seconds': 'actionDurationInSeconds'
        }

        self._period_in_seconds = None
        self._requests_limit = None
        self._action_duration_in_seconds = None

    @property
    def period_in_seconds(self):
        """
        **[Required]** Gets the period_in_seconds of this RequestRateLimitingConfiguration.
        Evaluation period in seconds.


        :return: The period_in_seconds of this RequestRateLimitingConfiguration.
        :rtype: int
        """
        return self._period_in_seconds

    @period_in_seconds.setter
    def period_in_seconds(self, period_in_seconds):
        """
        Sets the period_in_seconds of this RequestRateLimitingConfiguration.
        Evaluation period in seconds.


        :param period_in_seconds: The period_in_seconds of this RequestRateLimitingConfiguration.
        :type: int
        """
        self._period_in_seconds = period_in_seconds

    @property
    def requests_limit(self):
        """
        **[Required]** Gets the requests_limit of this RequestRateLimitingConfiguration.
        Requests allowed per evaluation period.


        :return: The requests_limit of this RequestRateLimitingConfiguration.
        :rtype: int
        """
        return self._requests_limit

    @requests_limit.setter
    def requests_limit(self, requests_limit):
        """
        Sets the requests_limit of this RequestRateLimitingConfiguration.
        Requests allowed per evaluation period.


        :param requests_limit: The requests_limit of this RequestRateLimitingConfiguration.
        :type: int
        """
        self._requests_limit = requests_limit

    @property
    def action_duration_in_seconds(self):
        """
        Gets the action_duration_in_seconds of this RequestRateLimitingConfiguration.
        Duration of block action application in seconds when `requestsLimit` is reached. Optional and can be 0 (no block duration).


        :return: The action_duration_in_seconds of this RequestRateLimitingConfiguration.
        :rtype: int
        """
        return self._action_duration_in_seconds

    @action_duration_in_seconds.setter
    def action_duration_in_seconds(self, action_duration_in_seconds):
        """
        Sets the action_duration_in_seconds of this RequestRateLimitingConfiguration.
        Duration of block action application in seconds when `requestsLimit` is reached. Optional and can be 0 (no block duration).


        :param action_duration_in_seconds: The action_duration_in_seconds of this RequestRateLimitingConfiguration.
        :type: int
        """
        self._action_duration_in_seconds = action_duration_in_seconds

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DiffSummary(object):
    """
    Response object for showing differences for a file between two revisions.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DiffSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param old_path:
            The value to assign to the old_path property of this DiffSummary.
        :type old_path: str

        :param new_path:
            The value to assign to the new_path property of this DiffSummary.
        :type new_path: str

        :param old_id:
            The value to assign to the old_id property of this DiffSummary.
        :type old_id: str

        :param new_id:
            The value to assign to the new_id property of this DiffSummary.
        :type new_id: str

        :param are_conflicts_in_file:
            The value to assign to the are_conflicts_in_file property of this DiffSummary.
        :type are_conflicts_in_file: bool

        :param is_large:
            The value to assign to the is_large property of this DiffSummary.
        :type is_large: bool

        :param is_binary:
            The value to assign to the is_binary property of this DiffSummary.
        :type is_binary: bool

        :param changes:
            The value to assign to the changes property of this DiffSummary.
        :type changes: list[oci.devops.models.DiffChunk]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DiffSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DiffSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'old_path': 'str',
            'new_path': 'str',
            'old_id': 'str',
            'new_id': 'str',
            'are_conflicts_in_file': 'bool',
            'is_large': 'bool',
            'is_binary': 'bool',
            'changes': 'list[DiffChunk]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'old_path': 'oldPath',
            'new_path': 'newPath',
            'old_id': 'oldId',
            'new_id': 'newId',
            'are_conflicts_in_file': 'areConflictsInFile',
            'is_large': 'isLarge',
            'is_binary': 'isBinary',
            'changes': 'changes',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._old_path = None
        self._new_path = None
        self._old_id = None
        self._new_id = None
        self._are_conflicts_in_file = None
        self._is_large = None
        self._is_binary = None
        self._changes = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def old_path(self):
        """
        Gets the old_path of this DiffSummary.
        The path on the base version to the changed object.


        :return: The old_path of this DiffSummary.
        :rtype: str
        """
        return self._old_path

    @old_path.setter
    def old_path(self, old_path):
        """
        Sets the old_path of this DiffSummary.
        The path on the base version to the changed object.


        :param old_path: The old_path of this DiffSummary.
        :type: str
        """
        self._old_path = old_path

    @property
    def new_path(self):
        """
        Gets the new_path of this DiffSummary.
        The path on the target version to the changed object.


        :return: The new_path of this DiffSummary.
        :rtype: str
        """
        return self._new_path

    @new_path.setter
    def new_path(self, new_path):
        """
        Sets the new_path of this DiffSummary.
        The path on the target version to the changed object.


        :param new_path: The new_path of this DiffSummary.
        :type: str
        """
        self._new_path = new_path

    @property
    def old_id(self):
        """
        Gets the old_id of this DiffSummary.
        The ID of the changed object on the base version.


        :return: The old_id of this DiffSummary.
        :rtype: str
        """
        return self._old_id

    @old_id.setter
    def old_id(self, old_id):
        """
        Sets the old_id of this DiffSummary.
        The ID of the changed object on the base version.


        :param old_id: The old_id of this DiffSummary.
        :type: str
        """
        self._old_id = old_id

    @property
    def new_id(self):
        """
        Gets the new_id of this DiffSummary.
        The ID of the changed object on the target version.


        :return: The new_id of this DiffSummary.
        :rtype: str
        """
        return self._new_id

    @new_id.setter
    def new_id(self, new_id):
        """
        Sets the new_id of this DiffSummary.
        The ID of the changed object on the target version.


        :param new_id: The new_id of this DiffSummary.
        :type: str
        """
        self._new_id = new_id

    @property
    def are_conflicts_in_file(self):
        """
        Gets the are_conflicts_in_file of this DiffSummary.
        Indicates whether the changed file contains conflicts.


        :return: The are_conflicts_in_file of this DiffSummary.
        :rtype: bool
        """
        return self._are_conflicts_in_file

    @are_conflicts_in_file.setter
    def are_conflicts_in_file(self, are_conflicts_in_file):
        """
        Sets the are_conflicts_in_file of this DiffSummary.
        Indicates whether the changed file contains conflicts.


        :param are_conflicts_in_file: The are_conflicts_in_file of this DiffSummary.
        :type: bool
        """
        self._are_conflicts_in_file = are_conflicts_in_file

    @property
    def is_large(self):
        """
        Gets the is_large of this DiffSummary.
        Indicates whether the file is large.


        :return: The is_large of this DiffSummary.
        :rtype: bool
        """
        return self._is_large

    @is_large.setter
    def is_large(self, is_large):
        """
        Sets the is_large of this DiffSummary.
        Indicates whether the file is large.


        :param is_large: The is_large of this DiffSummary.
        :type: bool
        """
        self._is_large = is_large

    @property
    def is_binary(self):
        """
        Gets the is_binary of this DiffSummary.
        Indicates whether the file is binary.


        :return: The is_binary of this DiffSummary.
        :rtype: bool
        """
        return self._is_binary

    @is_binary.setter
    def is_binary(self, is_binary):
        """
        Sets the is_binary of this DiffSummary.
        Indicates whether the file is binary.


        :param is_binary: The is_binary of this DiffSummary.
        :type: bool
        """
        self._is_binary = is_binary

    @property
    def changes(self):
        """
        **[Required]** Gets the changes of this DiffSummary.
        List of changed section in the file.


        :return: The changes of this DiffSummary.
        :rtype: list[oci.devops.models.DiffChunk]
        """
        return self._changes

    @changes.setter
    def changes(self, changes):
        """
        Sets the changes of this DiffSummary.
        List of changed section in the file.


        :param changes: The changes of this DiffSummary.
        :type: list[oci.devops.models.DiffChunk]
        """
        self._changes = changes

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DiffSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this DiffSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DiffSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this DiffSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DiffSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this DiffSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DiffSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this DiffSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class NetworkLoadBalancerClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.network_load_balancer.NetworkLoadBalancerClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new NetworkLoadBalancerClientCompositeOperations object

        :param NetworkLoadBalancerClient client:
            The service client which will be wrapped by this object
        """
        self.client = client

    def change_network_load_balancer_compartment_and_wait_for_state(self, network_load_balancer_id, change_network_load_balancer_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.change_network_load_balancer_compartment` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.ChangeNetworkLoadBalancerCompartmentDetails change_network_load_balancer_compartment_details: (required)
            The configuration details for moving a network load balancer to a different compartment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.change_network_load_balancer_compartment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.change_network_load_balancer_compartment(network_load_balancer_id, change_network_load_balancer_compartment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_backend_and_wait_for_state(self, network_load_balancer_id, create_backend_details, backend_set_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_backend` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.CreateBackendDetails create_backend_details: (required)
            The details to add a backend server to a backend set.

        :param str backend_set_name: (required)
            The name of the backend set to which to add the backend server.

            Example: `example_backend_set`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_backend`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_backend(network_load_balancer_id, create_backend_details, backend_set_name, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_backend_set_and_wait_for_state(self, network_load_balancer_id, create_backend_set_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_backend_set` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.CreateBackendSetDetails create_backend_set_details: (required)
            The details for adding a backend set.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_backend_set`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_backend_set(network_load_balancer_id, create_backend_set_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_listener_and_wait_for_state(self, network_load_balancer_id, create_listener_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_listener` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.CreateListenerDetails create_listener_details: (required)
            Details to add a listener.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_listener`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_listener(network_load_balancer_id, create_listener_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_network_load_balancer_and_wait_for_state(self, create_network_load_balancer_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_network_load_balancer` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param oci.network_load_balancer.models.CreateNetworkLoadBalancerDetails create_network_load_balancer_details: (required)
            Details for the new network load balancer.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.create_network_load_balancer`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_network_load_balancer(create_network_load_balancer_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_backend_and_wait_for_state(self, network_load_balancer_id, backend_set_name, backend_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_backend` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str backend_set_name: (required)
            The name of the backend set associated with the backend server.

            Example: `example_backend_set`

        :param str backend_name: (required)
            The name of the backend server to remove.
            If the backend was created with an explicitly specified name, that name should be used here.
            If the backend was created without explicitly specifying the name, but was created using ipAddress, this is specified as <ipAddress>:<port>.
            If the backend was created without explicitly specifying the name, but was created using targetId, this is specified as <targetId>:<port>.

            Example: `10.0.0.3:8080` or `ocid1.privateip..oc1.<var>&lt;unique_ID&gt;</var>:8080`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_backend`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_backend(network_load_balancer_id, backend_set_name, backend_name, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_backend_set_and_wait_for_state(self, network_load_balancer_id, backend_set_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_backend_set` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str backend_set_name: (required)
            The name of the backend set to delete.

            Example: `example_backend_set`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_backend_set`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_backend_set(network_load_balancer_id, backend_set_name, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_listener_and_wait_for_state(self, network_load_balancer_id, listener_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_listener` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str listener_name: (required)
            The name of the listener to delete.

            Example: `example_listener`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_listener`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_listener(network_load_balancer_id, listener_name, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_network_load_balancer_and_wait_for_state(self, network_load_balancer_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_network_load_balancer` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.delete_network_load_balancer`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_network_load_balancer(network_load_balancer_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_backend_and_wait_for_state(self, network_load_balancer_id, update_backend_details, backend_set_name, backend_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_backend` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.UpdateBackendDetails update_backend_details: (required)
            Details for updating a backend server.

        :param str backend_set_name: (required)
            The name of the backend set associated with the backend server.

            Example: `example_backend_set`

        :param str backend_name: (required)
            The name of the backend server to update.
            If the backend was created with an explicitly specified name, that name should be used here.
            If the backend was created without explicitly specifying the name, but was created using ipAddress, this is specified as <ipAddress>:<port>.
            If the backend was created without explicitly specifying the name, but was created using targetId, this is specified as <targetId>:<port>.

            Example: `10.0.0.3:8080` or `ocid1.privateip..oc1.<var>&lt;unique_ID&gt;</var>:8080`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_backend`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_backend(network_load_balancer_id, update_backend_details, backend_set_name, backend_name, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_backend_set_and_wait_for_state(self, network_load_balancer_id, update_backend_set_details, backend_set_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_backend_set` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.UpdateBackendSetDetails update_backend_set_details: (required)
            The details to update a backend set.

        :param str backend_set_name: (required)
            The name of the backend set to update.

            Example: `example_backend_set`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_backend_set`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_backend_set(network_load_balancer_id, update_backend_set_details, backend_set_name, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_health_checker_and_wait_for_state(self, network_load_balancer_id, update_health_checker_details, backend_set_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_health_checker` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.UpdateHealthCheckerDetails update_health_checker_details: (required)
            The health check policy configuration details.

        :param str backend_set_name: (required)
            The name of the backend set associated with the health check policy to be retrieved.

            Example: `example_backend_set`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_health_checker`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_health_checker(network_load_balancer_id, update_health_checker_details, backend_set_name, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_listener_and_wait_for_state(self, network_load_balancer_id, update_listener_details, listener_name, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_listener` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.UpdateListenerDetails update_listener_details: (required)
            Details to update a listener.

        :param str listener_name: (required)
            The name of the listener to update.

            Example: `example_listener`

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_listener`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_listener(network_load_balancer_id, update_listener_details, listener_name, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_network_load_balancer_and_wait_for_state(self, network_load_balancer_id, update_network_load_balancer_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_network_load_balancer` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.UpdateNetworkLoadBalancerDetails update_network_load_balancer_details: (required)
            The information to be updated.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_network_load_balancer`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_network_load_balancer(network_load_balancer_id, update_network_load_balancer_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_network_security_groups_and_wait_for_state(self, network_load_balancer_id, update_network_security_groups_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_network_security_groups` and waits for the :py:class:`~oci.network_load_balancer.models.WorkRequest`
        to enter the given state(s).

        :param str network_load_balancer_id: (required)
            The `OCID`__ of the network load balancer to update.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.network_load_balancer.models.UpdateNetworkSecurityGroupsDetails update_network_security_groups_details: (required)
            The details for updating the network security groups associated with the specified network load balancer.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.network_load_balancer.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.network_load_balancer.NetworkLoadBalancerClient.update_network_security_groups`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_network_security_groups(network_load_balancer_id, update_network_security_groups_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)
